Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/microsoft/vscode.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'src/vs/workbench/services/workingCopy/common/workingCopyHistoryTracker.ts')
-rw-r--r--src/vs/workbench/services/workingCopy/common/workingCopyHistoryTracker.ts3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/vs/workbench/services/workingCopy/common/workingCopyHistoryTracker.ts b/src/vs/workbench/services/workingCopy/common/workingCopyHistoryTracker.ts
index ed05ae2c5ff..7e3d7a7c2b4 100644
--- a/src/vs/workbench/services/workingCopy/common/workingCopyHistoryTracker.ts
+++ b/src/vs/workbench/services/workingCopy/common/workingCopyHistoryTracker.ts
@@ -193,7 +193,8 @@ export class WorkingCopyHistoryTracker extends Disposable implements IWorkbenchC
private shouldTrackHistory(resource: URI, stat: IFileStatWithMetadata): boolean {
if (
resource.scheme !== this.pathService.defaultUriScheme && // track history for all workspace resources
- resource.scheme !== Schemas.vscodeUserData // track history for all settings
+ resource.scheme !== Schemas.vscodeUserData && // track history for all settings
+ resource.scheme !== Schemas.inMemory // track history for tests that use in-memory
) {
return false; // do not support unknown resources
}